@@ -1,15 +1,68 @@
 package Net::Launchpad::Model::CVE;
-BEGIN {
-  $Net::Launchpad::Model::CVE::AUTHORITY = 'cpan:ADAMJS';
-}
 # ABSTRACT: CVE Model
-$Net::Launchpad::Model::CVE::VERSION = '1.2.1';
+$Net::Launchpad::Model::CVE::VERSION = '1.03';
+
+use Mojo::Base 'Net::Launchpad::Client';
+
+has 'cve' => '';
+
+sub by_sequence {
+    my ($self, $sequence) = @_;
+    $self->cve($self->get(sprintf("%s/bugs/cve/%s", $self->api_url, $sequence)));
+}
+
+sub bugs {
+    my $self = shift;
+    my $bugs = $self->get($self->cve->{bugs_collection_link});
+    return $bugs->{entries};
+}
+
+sub display_name {
+    my $self  = shift;
+    return $self->cve->{display_name};
+}
+
+sub description {
+    my $self = shift;
+    return $self->cve->{description};
+}
+
+sub title {
+    my $self = shift;
+    return $self->cve->{title};
+}
+
+sub web_link {
+    my $self = shift;
+    return $self->cve->{web_link};
+}
+
+sub date_created {
+    my $self = shift;
+    return $self->cve->{date_created};
+}
+
+sub date_modified {
+    my $self = shift;
+    return $self->cve->{date_modified};
+}
+
+sub status {
+    my $self = shift;
+    return $self->cve->{status};
+}
+
+sub url {
+    my $self = shift;
+    return $self->cve->{url};
+}
+
+sub sequence {
+    my $self = shift;
+    return $self->cve->{sequence};
+}
 
-use Moose;
-use namespace::autoclean;
-extends 'Net::Launchpad::Model::Base';
 
-__PACKAGE__->meta->make_immutable;
 1;
 
 __END__
@@ -24,7 +77,7 @@ Net::Launchpad::Model::CVE - CVE Model
 
 =head1 VERSION
 
-version 1.2.1
+version 1.03
 
 =head1 SYNOPSIS
 
@@ -34,11 +87,18 @@ version 1.2.1
         access_token        => '3243232',
         access_token_secret => '432432432'
     );
+    $c->staging(1);
 
-    my $cve = $c->cve('XXXX-XXXX');
+    my $cve = $c->model('CVE')->by_sequence('XXXX-XXXX');
 
-    print "Title: ". $cve->result->{title};
-    print "Desc:  ". $cve->result->{description};
+    print "Title: ". $cve->title;
+    print "Desc:  ". $cve->description;
+
+=head1 ATTRIBUTES
+
+=head2 cve
+
+CVE object.
 
 =head1 METHODS
 
@@ -46,10 +106,46 @@ version 1.2.1
 
 This needs to be called before any of the below methods. Takes a CVE sequence number, e.g. 2011-3188.
 
+=head2 sequence
+
+Returns cve number.
+
+=head2 title
+
+Returns title of cve.
+
 =head2 bugs
 
 Returns a list of entries associated with cve
 
+=head2 web_link
+
+Returns browseable URL link to resource.
+
+=head2 description
+
+Returns cve description
+
+=head2 status
+
+Returns whether the cve is of candidate, entry, deprecated
+
+=head2 date_created
+
+Returns date cve was created
+
+=head2 date_modified
+
+Return date of last modification
+
+=head2 display_name
+
+Returns brief description of the ref and state
+
+=head2 url
+
+Returns URL to site that contains CVE data for this CVE reference.
+
 =head1 AUTHOR
 
 Adam Stokes <adamjs@cpan.org>
